weaviate.schema.properties package
==================================

.. automodule:: weaviate.schema.properties
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.schema.properties.crud\_properties module
--------------------------------------------------

.. automodule:: weaviate.schema.properties.crud_properties
   :members:
   :undoc-members:
   :show-inheritance:
